==> pdfjs-dist-3.7.107.jar: META-INF/resources/webjars/pdfjs-dist/3.7.107/types/web/pdf_viewer.component.d.ts <==
import { AnnotationLayerBuilder } from "./annotation_layer_builder.js";
export class DefaultAnnotationLayerFactory {
}
export class DefaultStructTreeLayerFactory {
}
export class DefaultTextLayerFactory {
}
export class DefaultXfaLayerFactory {
}
import { DownloadManager } from "./download_manager.js";
import { EventBus } from "./event_utils.js";
import { GenericL10n } from "./genericl10n.js";
import { LinkTarget } from "./pdf_link_service.js";
import { NullL10n } from "./l10n_utils.js";
import { parseQueryString } from "./ui_utils.js";
import { PDFFindController } from "./pdf_find_controller.js";
import { PDFHistory } from "./pdf_history.js";
import { PDFLinkService } from "./pdf_link_service.js";
import { PDFPageView } from "./pdf_page_view.js";
import { PDFScriptingManager } from "./pdf_scripting_manager.js";
import { PDFSinglePageViewer } from "./pdf_single_page_viewer.js";
import { PDFViewer } from "./pdf_viewer.js";
import { ProgressBar } from "./ui_utils.js";
import { RenderingStates } from "./ui_utils.js";
import { ScrollMode } from "./ui_utils.js";
import { SimpleLinkService } from "./pdf_link_service.js";
import { SpreadMode } from "./ui_utils.js";
import { StructTreeLayerBuilder } from "./struct_tree_layer_builder.js";
import { TextLayerBuilder } from "./text_layer_builder.js";
import { XfaLayerBuilder } from "./xfa_layer_builder.js";
export { AnnotationLayerBuilder, DownloadManager, EventBus, GenericL10n, LinkTarget, NullL10n, parseQueryString, PDFFindController, PDFHistory, PDFLinkService, PDFPageView, PDFScriptingManager, PDFSinglePageViewer, PDFViewer, ProgressBar, RenderingStates, ScrollMode, SimpleLinkService, SpreadMode, StructTreeLayerBuilder, TextLayerBuilder, XfaLayerBuilder };

==> pdfjs-dist-4.0.189.jar: META-INF/resources/webjars/pdfjs-dist/4.0.189/types/web/pdf_viewer.component.d.ts <==
import { AnnotationLayerBuilder } from "./annotation_layer_builder.js";
import { DownloadManager } from "./download_manager.js";
import { EventBus } from "./event_utils.js";
import { FindState } from "./pdf_find_controller.js";
import { GenericL10n } from "./genericl10n.js";
import { LinkTarget } from "./pdf_link_service.js";
import { NullL10n } from "./l10n_utils.js";
import { parseQueryString } from "./ui_utils.js";
import { PDFFindController } from "./pdf_find_controller.js";
import { PDFHistory } from "./pdf_history.js";
import { PDFLinkService } from "./pdf_link_service.js";
import { PDFPageView } from "./pdf_page_view.js";
import { PDFScriptingManager } from "./pdf_scripting_manager.component.js";
import { PDFSinglePageViewer } from "./pdf_single_page_viewer.js";
import { PDFViewer } from "./pdf_viewer.js";
import { ProgressBar } from "./ui_utils.js";
import { RenderingStates } from "./ui_utils.js";
import { ScrollMode } from "./ui_utils.js";
import { SimpleLinkService } from "./pdf_link_service.js";
import { SpreadMode } from "./ui_utils.js";
import { StructTreeLayerBuilder } from "./struct_tree_layer_builder.js";
import { TextLayerBuilder } from "./text_layer_builder.js";
import { XfaLayerBuilder } from "./xfa_layer_builder.js";
export { AnnotationLayerBuilder, DownloadManager, EventBus, FindState, GenericL10n, LinkTarget, NullL10n, parseQueryString, PDFFindController, PDFHistory, PDFLinkService, PDFPageView, PDFScriptingManager, PDFSinglePageViewer, PDFViewer, ProgressBar, RenderingStates, ScrollMode, SimpleLinkService, SpreadMode, StructTreeLayerBuilder, TextLayerBuilder, XfaLayerBuilder };
